@@ -311,9 +311,9 @@ class ModerationData(NamedTuple):
 
 
 class RetractionData(NamedTuple):
-    id: str | None
+    id: str
     is_tombstone: bool
-    timestamp: float | None
+    timestamp: datetime
 
 
 class DiscoItems(NamedTuple):
@@ -480,7 +480,7 @@ class DiscoInfo(NamedTuple):
 
                 if dataform[var].type_ == "jid-multi":
                     return dataform[var].values or None
-                return dataform[var].value or None
+                return dataform[var].value
 
             except Exception:
                 continue
@@ -625,6 +625,21 @@ class DiscoInfo(NamedTuple):
     def muc_lang(self) -> Optional[Any]:
         return self.get_field_value(Namespace.MUC_INFO, "muc#roominfo_lang")
 
+    @property
+    def muc_allows_invites(self) -> bool | None:
+        return self.get_field_value(Namespace.MUC_INFO, "muc#roomconfig_allowinvites")
+
+    @property
+    def prosody_allow_member_invites(self) -> bool | None:
+        return self.get_field_value(
+            Namespace.MUC_INFO,
+            r"{http://prosody.im/protocol/muc}roomconfig_allowmemberinvites",
+        )
+
+    @property
+    def roomconfig_allowpm(self) -> str | None:
+        return self.get_field_value(Namespace.MUC_INFO, "muc#roomconfig_allowpm")
+
     @property
     def muc_is_persistent(self) -> bool:
         return "muc_persistent" in self.features
